@@ -4,6 +4,7 @@ knitr::opts_chunk$set(
    cache = FALSE,
    dpi = 75,
    fig.width = 6, fig.height = 6,
+   fig.keep = 'high',
   # comment = "#>",
   tidy = FALSE)
 
@@ -58,8 +59,10 @@ hmap(studentmigration[idx,idx], dominance = FALSE, col = my_palette, key = FALSE
 ## ----englishtowns , fig.width = 8, fig.height = 8------------------------
 
 data(Englishtowns)
-v<-slidevector(Englishtowns,2,250,.001)
+v<-slidevector(Englishtowns,dim = 2,itmax = 250, eps = .001)
 plot(v,col="blue",ylim=c(-150,300),xlim=c(-150,300))
+
+## ----englishtowns stress decomposition , fig.width = 8, fig.height = 8----
 q2 <- decomposition(v$resid)
 summary(q2)
 
